@@ -1,7 +1,7 @@
 package Perinci::CmdLine::POD;
 
-our $DATE = '2017-01-12'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2017-01-13'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict;
@@ -185,6 +185,9 @@ _
 
 A special value of `:self` means this script can complete itself.
 
+Without specifying this option, the COMPLETION POD section will not be
+generated.
+
 _
         },
     },
@@ -665,7 +668,7 @@ _
         # attributes in the hash (Moo/Mo issue?), we need to access the
         # attribute accessor method first to get them recorded in the hash. this
         # will be fixed in the dump module in the future.
-        local $0 = $args{script} if defined $args{script};
+        local $0 = $program_name;
         local @INC = ("lib", @INC);
         eval "use " . ref($cli) . "()";
         die if $@;
@@ -799,7 +802,7 @@ _
         # attributes in the hash (Moo/Mo issue?), we need to access the
         # attribute accessor method first to get them recorded in the hash. this
         # will be fixed in the dump module in the future.
-        local $0 = $args{script} if defined $args{script};
+        local $0 = $program_name;
         local @INC = ("lib", @INC);
         eval "use " . ref($cli) . "()";
         die if $@;
@@ -874,7 +877,7 @@ Perinci::CmdLine::POD - Generate POD for Perinci::CmdLine-based CLI script
 
 =head1 VERSION
 
-This document describes version 0.004 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2017-01-12.
+This document describes version 0.005 of Perinci::CmdLine::POD (from Perl distribution Perinci-CmdLine-POD), released on 2017-01-13.
 
 =head1 SYNOPSIS
 
@@ -909,6 +912,9 @@ Script name for shell completion.
 
 A special value of C<:self> means this script can complete itself.
 
+Without specifying this option, the COMPLETION POD section will not be
+generated.
+
 =item * B<config_dirs> => I<array[dirname]>
 
 =item * B<config_filename> => I<str|array[str]|array[hash]>
